Flags class

A run of Flag.

Inheritance

Constructors

Flags.fromCode(List<FlagsCode> countiyCodes, {Key? key, double height = 300, double width = 400, Widget replacement = const SizedBox.shrink(), FlagSize flagSize = FlagSize.size_4x3, double? borderRadius})
Creates a flag widget.
const
Flags.fromString(List<String> counties, {Key? key, double height = 300, double width = 400, Widget replacement = const SizedBox.shrink(), FlagSize flagSize = FlagSize.size_4x3, double? borderRadius})
Creates a flag widget.
const

Properties

borderRadius → double?
final
counties → List<String>
The flag to display.
final
countiyCodes → List<FlagsCode>
The flag to display. Enum value for FlagsCode.
final
flagSize → FlagSize
This is the each flag aspect ratio
final
hashCode → int
The hash code for this object.
no setterinherited
height → double
Requires the child to have exactly this height.
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
replacement → Widget
Replacement Widget, if flag not found.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
width → double
Requires the child to have exactly this width.
final

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

flagsCode → const List<String>
FlagsCode.